Public bug reported:
librocblas5 7.1.0-1ubuntu4 installs Tensile kernel libraries at
/usr/lib/x86_64-linux-gnu/rocblas/5.1.0/library/ for nine targets —
gfx908/90a/942/1030/1100/1101/1151/1200/1201 — but not gfx1150. The per-arch
Kernels.so-000-<arch>.hsaco set in the same directory has the same nine targets
and the same omission. On a gfx1150 machine every GEMM fails and the process
aborts.
Ubuntu 26.04 (resolute), kernel 7.0.0-28-generic.
Hardware: AMD Ryzen AI 9 HX 370 w/ Radeon 890M iGPU (Strix Point, gfx1150).
KFD reports gfx_target_version 110500; `rocminfo` (7.1.1-0ubuntu1) enumerates
the
GPU agent natively as gfx1150 with no HSA_OVERRIDE_GFX_VERSION set, and the HSA
runtime itself works: HIP kernels compiled at runtime (via hipcc/comgr paths,
e.g. from Julia's AMDGPU.jl) execute correctly on this device.
This report is filed manually (not via apport); happy to attach anything
else.
Reproducer:
// repro.cpp ; build: hipcc repro.cpp -lrocblas -o repro
#include <hip/hip_runtime.h>
#include <rocblas/rocblas.h>
#include <stdio.h>
int main(void) {
const int n = 4;
float *A, *B, *C;
hipMalloc((void **)&A, n * n * sizeof(float));
hipMalloc((void **)&B, n * n * sizeof(float));
hipMalloc((void **)&C, n * n * sizeof(float));
rocblas_handle h;
printf("create_handle: %d\n", (int)rocblas_create_handle(&h));
float alpha = 1.0f, beta = 0.0f;
rocblas_status s = rocblas_sgemm(h, rocblas_operation_none,
rocblas_operation_none, n, n, n, &alpha, A, n, B, n, &beta, C, n);
printf("sgemm: %d\n", (int)s);
hipDeviceSynchronize();
return 0;
}
Observed: create_handle succeeds, then:
rocBLAS error: Cannot read
/usr/lib/x86_64-linux-gnu/rocblas/5.1.0/library/TensileLibrary.dat:
No such file or directory for GPU arch : gfx1150
(an "Illegal seek" variant of the same message appears in other harnesses)
followed by SIGABRT (exit 134).
Expected: gfx1150 Tensile kernels — the build already covers every other current
consumer target including gfx1151 (Strix Halo), so this looks like a one-arch
omission — or at minimum rocblas_status_arch_mismatch returned to the caller
rather than abort().
** Affects: rocblas (Ubuntu)
Importance: Undecided
Status: New
--
You received this bug notification because you are a member of Ubuntu
Bugs, which is subscribed to Ubuntu.
https://bugs.launchpad.net/bugs/2162810
Title:
librocblas5 ships Tensile GEMM kernels for nine gfx targets including
gfx1151 but omits gfx1150; sgemm aborts on Strix Point
To manage notifications about this bug go to:
https://bugs.launchpad.net/ubuntu/+source/rocblas/+bug/2162810/+subscriptions
--
ubuntu-bugs mailing list
[email protected]
https://lists.ubuntu.com/mailman/listinfo/ubuntu-bugs